Converts a genind object to genlight object
gi2gl(gi, parallel = TRUE)-- a genind object
-- switch to deactivate parallel version. Default set to TRUE. Only for testing purpose.
A genlight object, with all slots filled.
Be aware due to ambiguity which one is the reference allele a combination of gi2gl(gl2gi(gl)) does not return an identical object (but in terms of analysis this conversions are equivalent)