The verbosity can be set in one of two ways -- (a) explicitly by the user by passing a value using the parameter verbose= in a function, or (b) by setting the verbosity globally as part of the r environment (gl.set.verbosity).
gl.check.verbosity(x = NULL)The verbosity, in variable verbose
User requested level of verbosity [default NULL].
Bernd Gruber (Post to https://groups.google.com/d/forum/dartr)