gl.filter.repavg: Filter loci in a genlight {adegenet} object based on average reproducibility of alleles at a locus
Description
SNP datasets generated by DArT have in index, RepAvg, generated by reproducing the data independently for 30% of loci.
RepAvg is the proportion of alleles that give a reproducible result, averaged over both alleles for each locus.
Usage
gl.filter.repavg(x, t = 1, v = 2)
Arguments
x
-- name of the genlight object containing the SNP data [required]
t
-- threshold value below which loci will be removed [default 0.95]
v
-- verbosity: 0, silent or fatal errors; 1, begin and end; 2, progress log ; 3, progress and results summary; 5, full report [default 2]
Value
Returns a genlight object retaining loci with a RepAvg greater than the specified threshold deleted.