gl.gene.freq: Calculate a statistic for each locus by group
An internal function essentially to convey readability to rather contorted R code.
It takes as input a genlight {adegenet} object with an index variable (say, population)
and calculates the selected statistic for each locus, broken down by the groups defined
by the index variable.
Description
Calculate a statistic for each locus by group
An internal function essentially to convey readability to rather contorted R code.
It takes as input a genlight {adegenet} object with an index variable (say, population)
and calculates the selected statistic for each locus, broken down by the groups defined
by the index variable.