Learn R Programming

dartR (version 1.8.3)

gl.grm: Calculates the genomic relatedness matrix

Description

The G matrix is calculated by centering the allele frequency matrix of the second allele by substracting 2 times the allefrequency

Usage

gl.grm(x, plotheatmap = TRUE, return.imputed = FALSE, verbose = NULL, ...)

Arguments

x

-- a genlight object

plotheatmap

-- a switch if a heatmap should be shown [Default:TRUE]

return.imputed

switch if loci with imputed data should be returned (see ?A.mat in package rrBLUP)

verbose

-- verbosity: 0, silent or fatal errors; 1, begin and end; 2, progress log ; 3, progress and results summary; 5, full report [default 2 or as specified using gl.set.verbosity]

...

parameters passed to function A.mat from package rrBLUP

Value

a genomic relatedness matrix

Examples

Run this code
# NOT RUN {
gl.grm(bandicoot.gl[1:5,1:10],plotheatmap=TRUE)  
# }

Run the code above in your browser using DataLab