Learn R Programming

dartR (version 1.0.5)

gl.report.callrate: Report summary of Call Rate for loci or individuals

Description

SNP datasets generated by DArT have missing values primarily arising from failure to call a SNP because of a mutation at one or both of the the restriction enzyme recognition sites. This script reports the number of missing values for each of several percentiles. The script gl.filter.callrate() will filter out the loci with call rates below a specified threshold.

Usage

gl.report.callrate(gl, method = "loc")

Arguments

gl

-- name of the genlight or genind object containing the SNP data [required]

method

specify the type of report by locus (method="loc") or individual (method="ind") [default method="loc"]

Value

Mean call rate by locus (method="loc") or individual (method="ind")

Examples

Run this code
# NOT RUN {
gl.report.callrate(testset.gl)
# }

Run the code above in your browser using DataLab