Name of the genlight object containing the SNP data [required].
type
Type of dendrogram "phylogram"|"cladogram"|"fan"|"unrooted"
[default "phylogram"].
outgroup
Vector containing the population names that are the outgroups
[deefault NULL].
labelsize
Size of the labels as a proportion of the graphics default
[default 0.7].
treefile
Name of the file for the tree topology using Newick format
[default NULL].
verbose
Specify the level of verbosity: 0, silent, fatal errors only;
1, flag function begin and end; 2, progress log; 3, progress and results
summary; 5, full report [default 2].