gl2treemix: Convert a genlight object to a treemix input file
Description
The output file contains the snp data in the format expected by treemix -- see the treemix manual. The file needs to be gzipped before it will be recognised
by treemix. Plotting functions can be obtained using source("C:/workspace/R/dartR/R/plotting_funcs.R").
Usage
gl2treemix(x, outfile = "treemix_input.gz", outpath = tempdir(),
v = 2)
Arguments
x
-- name of the genlight object containing the SNP data [required]
outfile
-- file name of the output file (including extension).
outpath
-- path where to save the output file (set to tempdir by default)
v
-- verbosity: 0, silent or fatal errors; 1, begin and end; 2, progress log ; 3, progress and results summary; 5, full report [default 2]
Details
Reference: Pickrell and Pritchard (2012). Inference of population splits and mixtures from genome-wide allele frequency data. PLoS Genetics https://doi.org/10.1371/journal.pgen.1002967