The locus metadata supplied by DArT has OneRatioRef, OneRatioSnp, PICRef, PICSnp, and AvgPIC included, but the allelic composition will change when some individuals,or populations, are removed from the dataset and so the initial statistics will no longer apply. This script recalculates these statistics and places the recalculated values in the appropriate place in the genlight object.
utils.recalc.avgpic(x, verbose = NULL)The modified genlight object.
Name of the genlight object containing the SNP data [required].
Verbosity: 0, silent or fatal errors; 1, begin and end; 2, progress log; 3, progress and results summary; 5, full report [default 2].
Custodian: Luis Mijangos (Post to https://groups.google.com/d/forum/dartr)
If the locus metadata OneRatioRef|Snp, PICRef|Snp and/or AvgPIC do not exist, the script creates and populates them.
utils.recalc.metrics for recalculating all metrics,
utils.recalc.callrate for recalculating CallRate,
utils.recalc.freqhomref for recalculating frequency of homozygous
reference, utils.recalc.freqhomsnp for recalculating frequency of
homozygous alternate, utils.recalc.freqhet for recalculating frequency
of heterozygotes, gl.recalc.maf for recalculating minor allele
frequency, gl.recalc.rdepth for recalculating average read depth
#out <- utils.recalc.avgpic(testset.gl)
Run the code above in your browser using DataLab