cbind.dartR: adjust cbind for dartR
Description
cbind is a bit lazy and does not take care for the metadata (so data in the
other slot is lost). You can get most of the loci metadata back using
gl.compliance.check.
Usage
# S3 method for dartR
cbind(...)
Arguments
- ...
list of dartR objects