gl.check.verbosity: Checks the current global verbosity
Description
The verbosity can be set in one of two ways -- (a) explicitly by the user by
passing a value using the parameter verbose= in a function, or (b) by setting
the verbosity globally as part of the r environment (gl.set.verbosity).
Usage
gl.check.verbosity(x = NULL)
Arguments
x
User requested level of verbosity [default NULL].
Value
The verbosity, in variable verbose