gl.filter.callrate: Filter loci or specimens in a genlight {adegenet} object based on call rate
Description
SNP datasets generated by DArT have missing values primarily arising from failure to call a SNP because of a mutation
at one or both of the the restriction enzyme recognition sites. This script filters out loci (or specimens) for which the call rate is
lower than a specified value. The script will also filter out loci (or specimens) in SilicoDArT (presence/absence) datasets where the call rate
is lower than the specified value. In this case, the data are missing owing to low coverage.