gl.filter.dups: Filter duplicated loci in a genlight {adegenet} object
Description
SNP datasets generated by DArT include fragments with more than one SNP and record them separately with the same CloneID (=AlleleID).
These multiple SNP loci within a fragment are likely to be linked, and so you may wish to remove duplicates.
This script filters out duplicate loci after ordering the genlight object on based on reproducibility, PIC in that order.
Usage
gl.filter.dups(gl)
Arguments
gl
-- name of the genlight object containing the SNP data, or the genind object containing the SilocoDArT data [required]
Value
The reduced genlight or genind object, plus a summary