Learn R Programming

dartR (version 0.80)

gl.filter.monomorphs: Remove monomorphic loci, including those with all NAs

Description

This script deletes monomorphic loci from a genlight {adegenet} object

Usage

gl.filter.monomorphs(gl, probar = FALSE)

Arguments

gl

-- name of the input genlight object [required]

probar

-- switch to output progress bar [default is false]

Value

A genlight object with monomorphic loci removed

Details

A DArT dataset will not have monomorphic loci, but they can arise when populations are deleted by assignment or by using the delete option in gl.pop.recode(). Retaining monomorphic loci unnecessarily increases the size of the dataset.

Examples

Run this code
# NOT RUN {
gl <- gl.filter.monomorphs(testset.gl)
# }

Run the code above in your browser using DataLab