Learn R Programming

dartR (version 1.0)

gl.filter.repavg: Filter loci in a genlight {adegenet} object based on average reproducibility of alleles at a locus

Description

SNP datasets generated by DArT have in index, RepAvg, generated by reproducing the data independently for 30% of loci. RepAvg is the proportion of alleles that give a reproducible result, averaged over both alleles for each locus.

Usage

gl.filter.repavg(gl, t = 1)

Arguments

gl

-- name of the genlight object containing the SNP data [required]

t

-- threshold value below which loci will be removed [default 0.95]

Value

Returns a genlight object retaining loci with a RepAvg less than the specified threshold deleted.

Examples

Run this code
# NOT RUN {
gl.report.repavg(testset.gl)
result <- gl.filter.repavg(testset.gl, t=0.95)
# }

Run the code above in your browser using DataLab