gl.filter.secondaries: Filter loci that represent secondary SNPs in a genlight {adegenet} object
Description
SNP datasets generated by DArT include fragments with more than one SNP and record them separately with the same CloneID (=AlleleID).
These multiple SNP loci within a fragment (secondaries) are likely to be linked, and so you may wish to remove secondaries.
This script filters out loci after ordering the genlight object on based on reproducibility, PIC in that order.
Usage
gl.filter.secondaries(gl)
Arguments
gl
-- name of the genlight object containing the SNP data [required]