-- a switch if a heatmap should be shown [Default:TRUE]
return.imputed
switch if loci with imputed data should be returned (see ?A.mat in package rrBLUP)
verbose
-- verbosity: 0, silent or fatal errors; 1, begin and end; 2, progress log ; 3, progress and results summary; 5, full report [default 2 or as specified using gl.set.verbosity]
...
parameters passed to function A.mat from package rrBLUP