This script takes the data on SNP genotypes for individuals and undertakes a Gower PCoa ordination using Euclidean distance and drawing upon
data in the original genlight {adegenet} object (entity x attribute matrix).
The script is essentially a wrapper for glPca() {adegenet} with default settings apart from setting parallel=FALSE and
converting the eigenvalues to percentages.
Usage
gl.pcoa(gl, nfactors = 5)
Arguments
gl
Name of the genlight object containing the SNP genotypes by specimen and population [required]
nfactors
Number of dimensions to retain in the output file [default 5]
Value
An object of class glPca containing the eigenvalues, factor scores and factor loadings