Learn R Programming

dartR (version 0.80)

gl.percent.freq: Generate percentage allele frequencies by locus and population

Description

This is a support script, to take SNP data or SilocoDArT presence/absence data grouped into populations in a genelight or genind object {adegenet} and generate a table of allele frequencies for each population and locus

Usage

gl.percent.freq(gl)

Arguments

gl

-- name of the genlight containing the SNP genotypes or genind object containing the presence/absence data [required]

Value

A matrix with allele frequencies (genelight) or presence/absence frequencies (genind) broken down by population and locus

Examples

Run this code
# NOT RUN {
m <-  gl.percent.freq(testset.gl)
m
# }

Run the code above in your browser using DataLab