gl.report.overshoot: Reports loci for which the SNP has been trimmed from the sequence tag
along with the adaptor
Description
This function checks the position of the SNP within the trimmed sequence tag
and identifies those for which the SNP position is outside the trimmed
sequence tag. This can happen, rarely, when the sequence containing the SNP
resembles the adaptor.
If TRUE, saves any ggplots and listings to the session
temporary directory (tempdir) [default FALSE].
verbose
Verbosity: 0, silent or fatal errors; 1, begin and end; 2,
progress log; 3, progress and results summary; 5, full report
[default NULL, unless specified using gl.set.verbosity].
Value
An unaltered genlight object
Details
The SNP genotype can still be used in most analyses, but functions like
gl2fasta() will present challenges if the SNP has been trimmed from the
sequence tag.
Resultant ggplot(s) and the tabulation(s) are saved to the session's
temporary directory.