Learn R Programming

dartR (version 1.0)

gl.report.pa: Report number of private alleles possessed by an individual of unknown provenance

Description

This script calculates the number of private alleles possessed by a focal individual of unknown provenance when compared to a series of target populations.

Usage

gl.report.pa(gl, id, nmin = 10, t = 0)

Arguments

gl

-- name of the input genlight object [required]

id

-- identity label of the focal individual whose provenance is unknown [required]

nmin

-- minimum sample size for a target population to be included in the analysis [default 10]

t

-- populations to retain in the output genlight object; those for which the focal individual has less than or equal to t loci with private alleles [default 0]

Value

A genlight object containing the focal individual (assigned to population "unknown") and populations for which the focal individual is not distinctive (number of loci with private alleles less than or equal to thresold t.

Examples

Run this code
# NOT RUN {
# Test run with a focal individual from the Macleay River (EmmacMaclGeor)
x <- gl.report.pa(testset.gl, id="UC_00146", nmin=10, t=1)

# }

Run the code above in your browser using DataLab